# Installation

Preferred way to install is as usual (for testing or in isolation):

```console
❯ pipx install mapology
```

For production use or within a virtual python env:

```console
❯ python -m pip install mapology
```
